/**
 * Copyright (C) 2011 - 101loops.com <dev@101loops.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.crashnote.core.collect.impl.excp;

import com.crashnote.core.collect.BaseCollector;
import com.crashnote.core.config.*;
import com.crashnote.core.model.data.*;

/**
 * Collector for serializing a {@link Throwable} into a structured form.
 * The actual work is deferred to the {@link ExcpStackCollector}.
 */
public class ExcpCollector<C extends Config>
        extends BaseCollector<C> implements IConfigChangeListener<C> {

    // configuration settings:
    private Long startupTime;

    private final ExcpStackCollector<C> excpStackCollector;

    // SETUP ======================================================================================

    public ExcpCollector(final C config) {
        super(config);
        updateConfig(config);
        this.excpStackCollector = createStackCollector(config);
    }

    public void updateConfig(final C config) {
        config.addListener(this);
        this.startupTime = config.getStartTime();
    }

    // INTERFACE ==================================================================================

    public DataArray collect(final Throwable th) {
        return buildException(th);
    }

    // SHARED =====================================================================================

    public DataArray buildException(final Object th) {
        if (th == null) return null;
        final DataArray excps = createDataArr();
        {
            Object e = th;
            while (e != null) {
                excps.add(buildExceptionTrace(e));
                e = getExcpCause(e);
            }
        }
        if (excps.size() == 0) return null;
        return excps;
    }

    protected DataObject buildExceptionTrace(final Object th) {
        final Throwable t = ((Throwable) th);
        return excpStackCollector.collectTrace(t.getMessage(), t.getClass().getName(), t.getStackTrace());
    }

    protected Object getExcpCause(final Object th) {
        return ((Throwable) th).getCause();
    }

    // FACTORY ====================================================================================

    protected ExcpStackCollector<C> createStackCollector(final C config) {
        return new ExcpStackCollector<C>(config);
    }

    // GET ========================================================================================

    public ExcpStackCollector<C> getExcpStackCollector() {
        return excpStackCollector;
    }

    public Long getStartupTime() {
        return startupTime;
    }
}