/**
 * Copyright (C) 2011 - 101loops.com <dev@101loops.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.crashnote.core.report.impl.session;

import com.crashnote.core.model.log.LogEvt;

import java.util.*;

/**
 * This class represents a collection of log events.
 */
public class LogHeap {

    /**
     * list of exceptions
     */
    private final List<LogEvt<?>> excps;

    // SETUP ======================================================================================

    public LogHeap() {
        this.excps = new ArrayList<LogEvt<?>>(5);
    }

    /**
     * Copy-Constructor
     */
    public LogHeap(final LogHeap heap) {

        // make a copy of the excp list
        this.excps = new ArrayList<LogEvt<?>>(heap.excps);

        // and then defer this
        defer();
    }

    // INTERFACE ==================================================================================

    /**
     * By deferring the local members, copies of the references they contain are created
     * - thus they can be processed in a separate thread
     */
    public void defer() {
        for (final LogEvt e : excps) e.defer();
    }

    public boolean isEmpty() {
        return excps.isEmpty();
    }

    public void addEvt(final LogEvt<?> evt) {
        if (evt.isExcp())
            excps.add(evt);
    }

    // GET ========================================================================================

    public LogEvt<?>[] getEvents() {
        int i = 0;
        final LogEvt<?>[] res = new LogEvt<?>[getExcpCount()];
        for (final LogEvt<?> e : excps) res[i++] = e;
        return res;
    }

    public int getExcpCount() {
        return excps.size();
    }
}
